@@ -698,7 +698,7 @@ class Dataset:
             return self._encode_property(list(var))
         elif isinstance(var, datetime.datetime):
             return str(var)
-        elif isinstance(var, np.str):
+        elif isinstance(var, str):
             return str(var)
         else:
             return var
